********
bytecode
********

``bytecode`` is a Python module to generate and modify bytecode.

* `bytecode project homepage at GitHub
  <https://github.com/MatthieuDartiailh/bytecode>`_ (code, bugs)
* `bytecode documentation
  <https://bytecode.readthedocs.io/>`_ (this documentation)
* `Download latest bytecode release at the Python Cheeseshop (PyPI)
  <https://pypi.python.org/pypi/bytecode>`_


Table Of Contents
=================

.. toctree::
   :maxdepth: 3

   usage
   cfg
   api
   peephole
   byteplay_codetransformer
   changelog
   todo


See also
========

* `codetransformer
  <https://pypi.python.org/pypi/codetransformer>`_
* `byteplay
  <https://github.com/serprex/byteplay>`_
* `byteasm
  <https://github.com/zachariahreed/byteasm>`_: an "assembler" for Python 3
  bytecodes.
* `BytecodeAssembler <https://pypi.python.org/pypi/BytecodeAssembler>`_
* `PEP 511 -- API for code transformers
  <https://www.python.org/dev/peps/pep-0511/>`_

